#
# spec file for package konqueror
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf5_version 5.26.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           konqueror
Version:        18.12.3
Release:        lp151.2.4.1
Summary:        KDE File Manager and Browser
# Note for legal: konqueror-17.04.2/webenginepart/autotests/webengine_testutils.h is Qt commercial OR GPL-3.0
# but it is neither built nor installed in our package.
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org/
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch:          Make-konqueror-open-a-window-even-if-already-running.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  kactivities5-devel >= 5.7.0
BuildRequires:  karchive-devel >= 5.7.0
BuildRequires:  kcmutils-devel >= 5.7.0
BuildRequires:  kcrash-devel >= 5.7.0
BuildRequires:  kded-devel >= 5.7.0
BuildRequires:  kdelibs4support-devel >= 5.7.0
BuildRequires:  kdesu-devel >= 5.7.0
BuildRequires:  kdoctools-devel >= 5.7.0
BuildRequires:  kf5-filesystem
BuildRequires:  khtml-devel >= 5.7.0
BuildRequires:  kparts-devel >= 5.7.0
BuildRequires:  kwallet-devel
BuildRequires:  libtidy-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Script) >= 5.2.0
BuildRequires:  pkgconfig(Qt5WebEngine) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2.0
BuildRequires:  pkgconfig(Qt5X11Extras) >= 5.2.0
Recommends:     %{name}-lang
Recommends:     dolphin-part
Recommends:     kwebkitpart
Obsoletes:      kde-baseapps5-libkonq < %{version}
Provides:       kde-baseapps5-libkonq = %{version}
Obsoletes:      kde-baseapps-libkonq < %{version}
Provides:       kde-baseapps-libkonq = %{version}
Obsoletes:      %{name}-libkonq < %{version}
Provides:       %{name}-libkonq = %{version}
Obsoletes:      kdebase4-libkonq
Obsoletes:      libKF5Konq6 < 17.04
Provides:       libKF5Konq6 = 17.04
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 mips mips64
# Needed for 42.3
%if 0%{?suse_version} < 1330
# It does not build with the default compiler (GCC 4.8) on Leap 42.x
%if 0%{?sle_version} < 120300
BuildRequires:  gcc6-c++
%else
BuildRequires:  gcc7-c++
%endif
%endif

%description
Konqueror allows you to manage your files and browse the web in a
unified interface.

%package -n webenginepart
Summary:        KDE WebEngine web browser component
Group:          System/GUI/KDE

%description -n webenginepart
This package contains a HTML rendering engine for Konqueror that is based on QtWebEngine.

%package -n konqueror-plugins
Summary:        KDE File Manager and Browser
Group:          Productivity/Networking/Web/Browsers
Requires:       %{name} = %{version}
Obsoletes:      fsview5 < %{version}
Provides:       fsview5 = %{version}
Obsoletes:      konqueror5-plugins < %{version}
Provides:       konqueror5-plugins = %{version}

%description -n konqueror-plugins
These plugins extend the functionality of Konqueror.

%package  devel
Summary:        KDE Konqueror Libraries: Build Environment
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Obsoletes:      kdebase4-devel
# FIXME 4.x variants of DBus interfaces need to go to devel package
Obsoletes:      kde-baseapps5-devel < %{version}
Provides:       kde-baseapps5-devel = %{version}
Obsoletes:      kde-baseapps-devel < %{version}
Provides:       kde-baseapps-devel = %{version}
Obsoletes:      libkonq-devel < %{version}
Provides:       libkonq-devel = %{version}

%description devel
Development package for the konqueror libraries.

%lang_package

%prep
%setup -q
%autopatch -p1

%build
  %if 0%{?suse_version} < 1330
    # It does not build with the default compiler (GCC 4.8) on Leap 42.x
    %if 0%{?sle_version} < 120300
      export CC=gcc-6
      export CXX=g++-6
    %else
      export CC=gcc-7
      export CXX=g++-7
    %endif
  %endif
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --all-name
    %{kf5_find_htmldocs}
  %endif

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post   -n konqueror-plugins -p /sbin/ldconfig
%postun -n konqueror-plugins -p /sbin/ldconfig

%files
%license COPYING*
%config %{_kf5_configdir}/autostart/konqy_preload.desktop
%config %{_kf5_configdir}/konqueror.categories
%dir %{_kf5_appstreamdir}
%dir %{_kf5_configkcfgdir}
%dir %{_kf5_datadir}
%dir %{_kf5_plugindir}
%dir %{_kf5_servicesdir}
%dir %{_kf5_servicetypesdir}
%dir %{_kf5_sharedir}/kcontrol
%dir %{_kf5_sharedir}/kcontrol/pics
%dir %{_kf5_sharedir}/khtml
%dir %{_kf5_sharedir}/khtml/kpartplugins
%dir %{_kf5_sharedir}/kwebkitpart
%dir %{_kf5_sharedir}/kwebkitpart/kpartplugins
%dir %{_kf5_sharedir}/webenginepart/kpartplugins
%dir %{_kf5_sharedir}/kxmlgui5
%doc %lang(en) %{_kf5_htmldir}/en
%{_datadir}/kcmcss/
%{_kf5_applicationsdir}/kfmclient.desktop
%{_kf5_applicationsdir}/kfmclient_dir.desktop
%{_kf5_applicationsdir}/kfmclient_html.desktop
%{_kf5_applicationsdir}/kfmclient_war.desktop
%{_kf5_applicationsdir}/konqbrowser.desktop
%{_kf5_appstreamdir}/org.kde.konqueror.appdata.xml
%{_kf5_bindir}/kfmclient
%{_kf5_bindir}/konqueror
%{_kf5_configkcfgdir}/konqueror.kcfg
%{_kf5_datadir}/kbookmark/
%{_kf5_dbusinterfacesdir}/org.kde.Konqueror.Main.xml
%{_kf5_dbusinterfacesdir}/org.kde.Konqueror.MainWindow.xml
%{_kf5_iconsdir}/hicolor/*/*/konqueror.*
%{_kf5_libdir}/libKF5Konq.so.*
%{_kf5_libdir}/libkdeinit5_kfmclient.so
%{_kf5_libdir}/libkdeinit5_konqueror.so
%{_kf5_libdir}/libkonquerorprivate.so.*
%{_kf5_plugindir}/kcm_bookmarks.so
%{_kf5_plugindir}/kcm_konq.so
%{_kf5_plugindir}/kcm_konqhtml.so
%{_kf5_plugindir}/kcm_performance.so
%{_kf5_plugindir}/konq_aboutpage.so
%{_kf5_servicesdir}/bookmarks.desktop
%{_kf5_servicesdir}/filebehavior.desktop
%{_kf5_servicesdir}/kcmkonqyperformance.desktop
%{_kf5_servicesdir}/kcmperformance.desktop
%{_kf5_servicesdir}/khtml_*.desktop
%{_kf5_servicesdir}/konq_aboutpage.desktop
%{_kf5_servicesdir}/org.kde.konqueror.desktop
%{_kf5_servicetypesdir}/konqaboutpage.desktop
%{_kf5_sharedir}/kcontrol/pics/onlyone.png
%{_kf5_sharedir}/kcontrol/pics/overlapping.png
%{_kf5_sharedir}/konqueror/

%files -n webenginepart
%license COPYING*
%{_kf5_libdir}/libkwebenginepartlib.so
%{_kf5_iconsdir}/hicolor/*/*/webengine.*
%{_kf5_kxmlguidir}/webenginepart/
%{_kf5_plugindir}/kf5/
%{_kf5_servicesdir}/webenginepart.desktop
%dir %{_kf5_sharedir}/webenginepart/
%{_kf5_sharedir}/webenginepart/error.html

%files -n konqueror-plugins
%license COPYING*
%{_kf5_bindir}/fsview
%{_kf5_plugindir}/fsviewpart.so
%{_kf5_sharedir}/fsview/
%{_kf5_iconsdir}/hicolor/*/apps/fsview.png
%{_kf5_servicesdir}/fsview_part.desktop
%{_kf5_plugindir}/webarchiverplugin.so
%{_kf5_plugindir}/webarchivethumbnail.so
%{_kf5_plugindir}/validatorsplugin.so
%{_kf5_plugindir}/akregatorkonqfeedicon.so
%{_kf5_plugindir}/babelfishplugin.so
%{_kf5_plugindir}/domtreeviewerplugin.so
%{_kf5_plugindir}/khtmlsettingsplugin.so
%{_kf5_plugindir}/minitoolsplugin.so
%{_kf5_plugindir}/dirfilterplugin.so
%{_kf5_plugindir}/konq_shellcmdplugin.so
%{_kf5_plugindir}/autorefresh.so
%{_kf5_plugindir}/kimgallery.so
%{_kf5_plugindir}/rellinksplugin.so
%{_kf5_plugindir}/searchbarplugin.so
%{_kf5_iconsdir}/*/*/actions/imagegallery.png
%{_kf5_iconsdir}/*/*/actions/webarchiver.png
%{_kf5_iconsdir}/*/*/actions/cssvalidator.png
%{_kf5_iconsdir}/*/*/actions/htmlvalidator.*
%{_kf5_iconsdir}/*/*/actions/validators.*
%{_kf5_iconsdir}/*/*/actions/babelfish.*
%{_kf5_sharedir}/akregator/
%{_kf5_sharedir}/domtreeviewer/
%{_kf5_sharedir}/khtml/kpartplugins/plugin_webarchiver.*
%{_kf5_sharedir}/khtml/kpartplugins/plugin_validators.*
%{_kf5_sharedir}/khtml/kpartplugins/akregator_konqfeedicon.*
%{_kf5_sharedir}/khtml/kpartplugins/plugin_babelfish.*
%{_kf5_sharedir}/khtml/kpartplugins/plugin_translator.*
%{_kf5_sharedir}/khtml/kpartplugins/autorefresh.*
%{_kf5_sharedir}/khtml/kpartplugins/plugin_rellinks.*
%{_kf5_sharedir}/khtml/kpartplugins/khtmlsettingsplugin.*
%{_kf5_sharedir}/khtml/kpartplugins/minitoolsplugin.*
%{_kf5_sharedir}/khtml/kpartplugins/plugin_domtreeviewer.*
%{_kf5_sharedir}/kwebkitpart/kpartplugins/plugin_validators.*
%{_kf5_sharedir}/kwebkitpart/kpartplugins/akregator_konqfeedicon.*
%{_kf5_sharedir}/kwebkitpart/kpartplugins/plugin_babelfish.*
%{_kf5_sharedir}/kwebkitpart/kpartplugins/plugin_translator.*
%{_kf5_sharedir}/kwebkitpart/kpartplugins/autorefresh.*
%{_kf5_sharedir}/kwebkitpart/kpartplugins/khtmlsettingsplugin.*
%{_kf5_sharedir}/webenginepart/kpartplugins/akregator_konqfeedicon.desktop
%{_kf5_sharedir}/webenginepart/kpartplugins/akregator_konqfeedicon.rc
%{_kf5_sharedir}/webenginepart/kpartplugins/autorefresh.desktop
%{_kf5_sharedir}/webenginepart/kpartplugins/autorefresh.rc
%{_kf5_sharedir}/webenginepart/kpartplugins/khtmlsettingsplugin.desktop
%{_kf5_sharedir}/webenginepart/kpartplugins/khtmlsettingsplugin.rc
%{_kf5_sharedir}/webenginepart/kpartplugins/plugin_babelfish.rc
%{_kf5_sharedir}/webenginepart/kpartplugins/plugin_translator.desktop
%{_kf5_sharedir}/webenginepart/kpartplugins/plugin_validators.desktop
%{_kf5_sharedir}/webenginepart/kpartplugins/plugin_validators.rc
%{_kf5_servicesdir}/webarchivethumbnail.desktop
%{_kf5_servicesdir}/akregator_konqplugin.desktop
%{_kf5_configkcfgdir}/validators.kcfg
%{_kf5_debugdir}/akregatorplugin.categories
%config %{_kf5_configdir}/translaterc
%dir %{_kf5_sharedir}/dolphinpart
%{_kf5_sharedir}/dolphinpart/kpartplugins/

%files devel
%license COPYING*
#doc README
%{_kf5_cmakedir}/KF5Konq/
%{_kf5_libdir}/libKF5Konq.so
%{_kf5_includedir}/

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Tue May 19 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add Make-konqueror-open-a-window-even-if-already-running.patch to
  fix konqueror not opening a window if it is closed and started a
  second time (boo#1075663, kde#388333)
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Fix license
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix all plugin ui.rc/metadata to be also installed for webenginepart
  * Fix error page to have UTF-8 encoding set as needed
  * Fix ui.rc files to use non-deprecated <gui> and to match DOCTYPE
  * Fix WebEngineTextExtension::completeText a bit
  * Remove unused find_package for Qt5Xml
  * Fix KF5_MIN_VERSION to match API used by code for some releases
  * Properly support BUILD_TESTING
  * Do not duplicated work of KAboutData::setupCommandLine()
  * Use same konqueror.org homepage everywhere
  * Remove duplicated cmake_minimum_required from libkonq, was resetting things
  * Remove usage of dead QT_USE_FAST_CONCATENATION
  * Remove unneeded moc includes
  * Use more https in links
  * Fix typo in include directory
  * Fix broken-by-kf5-port installation of some icons
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * actually initialize kcrash properly
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Fix build with Qt 5.12
  * Add donation url to appdata
  * Ask the user what to do in case of a SSL certificate error
  * Fix handling of cookies without a domain
  * File Size View: Fix KProtocolInfoFactory assert
  * Fix removing cookies from KCookieServer
  * use QIcon::fromTheme() instead of QIcon()
  * Add basic tests for WebEnginePartCookieJar
  * Fix minor EBN issues and minor porting
  * Fix compilation
  * Fix minor EBN issues [includes]
  * Replace KStatusBar with QStatusBar
  * Remove KIcon from plugins
  * Remove call to hasSubUrl
  * Remove KUrl from autorefresh, dirfilter, domtreeview and fsview plugins
  * Fix minor EBN issues
  * Fix the workaround for cookie expiration date in WebEnginePart
  * Don't define WebEnginePartCookieJar::filterCookie for old versions of Qt
  * Synchronize cookies between QWebEngine and KCookieServer
  * Fix issue with info protocol and refresh
  * Restore ability to view help pages from Konqueror
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Sat Jul 28 2018 wbauer@tmo.at
- Build with gcc7 on Leap 42.3, it doesn't compile with 4.8 anymore
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Restore the ability to view man and info pages from Konqueror
  * Display an error page for error URLs in WebEnginePart
  * Do not duplicate work of KAboutData::setupCommandLine()
  * Akregator feed detector plugin: Use new connect() syntax
  * Akregator feed detector plugin: Make PluginBase just a namespace
  * Akregator feed detector plugin: Restore the popup menu action
  * Akregator feed detector plugin: Port away from KDELibs4Support
  * Akregator feed detector plugin: Do not crash for an invalid URL
  * Fix test failure once D12206 lands
  * Fix test failure when D11569 lands
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Load translation catalog webenginepart
  * Include zlib also on build time
  * Add back KWallet support to Konqueror
  * Fix i18n usage
- Dropped patches, now upstream:
  * add-kwallet-support-to-webengine.patch
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Sat Mar  3 2018 wbauer@tmo.at
- Add add-kwallet-support-to-webengine.patch to allow storing user
  names and passwords in kwallet when using the webenginepart
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Sat Jan 20 2018 wbauer@tmo.at
- Fix package summary and description
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Give a name to the menus in the webenginepart (kde#386714)
  * New maintainer for Konqueror: Stefano Crocco
  * Repair konqviewmgrtest by disabling creation of preloaded windows.
  * Bundle the ui.rc file into a qrc resource.
  * Fix download behavior when using webengine part
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Sun Oct 29 2017 fabian@ritter-vogt.de
- Don't try to install Home.desktop in /usr/share/applications,
  the copy from plasma5-workspace (by kio_desktop) should be used
  instead (boo#1058743)
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Fri Jul  7 2017 wbauer@tmo.at
- Recommend dolphin-part to make file management work out of the
  box (boo#1047665)
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Fix build with Qt 5.9 (kde#377490)
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * Port kde4_add_app_icon to ecm_add_app_icon
  * Save/restore window size
  * Accept single line command options like we used to do
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * rename define, to match kdepim
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Tue Dec 13 2016 wbauer@tmo.at
- Recommend kwebkitpart again instead of webenginepart for now, the
  latter crashes currently with Qt 5.7.1 (same reason as
  QTCREATORBUG-17296) and still lacks some KDE integration (e.g.
  storing passwords in kwallet, kde#372777)
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Sun Nov 27 2016 tittiatcoke@gmail.com
- Update spec-files to be consistent wiht KA
